@@ -47,6 +47,8 @@ use KinoSearch::Index::FieldsReader;
 use KinoSearch::Index::FieldInfos;
 use KinoSearch::Index::TermVector;
 
+use Storable qw( dclone );
+
 sub init_instance {
     my $self = shift;
 
@@ -61,6 +63,11 @@ sub init_instance {
     }
 }
 
+sub clone {
+    my $self = shift;
+    return dclone($self);
+}
+
 # Given two Field objects, return a child which has all the positive
 # attributes of both parents (meaning: values are OR'd).
 sub breed_with {
@@ -281,7 +288,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
 
