@@ -12,7 +12,7 @@ BEGIN {
         analyzer       => undef,
         formatter      => undef,
         encoder        => undef,
-        terms          => [],
+        terms          => undef,
         excerpt_length => 200,
         pre_tag        => undef,                  # back compat
         post_tag       => undef,                  # back compat
@@ -31,6 +31,7 @@ sub init_instance {
     my $self = shift;
     croak("Missing required arg 'excerpt_field'")
         unless defined $self->{excerpt_field};
+    $self->{terms} = [];
 
     # assume HTML
     if ( !defined $self->{encoder} ) {
@@ -260,9 +261,15 @@ TERM: for my $term ( @{ $self->{terms} } ) {
         }
     }
 
-    # sort and return
-    @posits = sort { $a->[0] <=> $b->[0] } @posits;
-    return \@posits;
+    # sort, uniquify and return
+    @posits = sort { $a->[0] <=> $b->[0] || $b->[1] <=> $a->[1] } @posits;
+    my @unique;
+    my $last = ~0;
+    for (@posits) {
+        push @unique, $_ if $_->[0] != $last;
+        $last = $_->[0];
+    }
+    return \@unique;
 }
 
 =for comment 
@@ -384,6 +391,6 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
