@@ -10,11 +10,16 @@ BEGIN {
         invindex => undef,
         filename => undef,
         # members
-        entries => {},
+        entries => undef,
         merged  => 0,
     );
 }
 
+sub init_instance {
+    my $self = shift;
+    $self->{entries} = {};
+}
+
 # Add a file to the list of files-to-merge.
 sub add_file {
     my ( $self, $filename ) = @_;
@@ -82,7 +87,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
