@@ -13,8 +13,8 @@ our @EXPORT_OK;
 BEGIN {
     __PACKAGE__->init_instance_vars(
         # members
-        by_name   => {},
-        by_num    => [],
+        by_name   => undef,
+        by_num    => undef,
         from_file => 0,
     );
     __PACKAGE__->ready_get_set(qw( from_file ));
@@ -27,7 +27,28 @@ BEGIN {
 }
 
 use KinoSearch::Document::Field;
-use Clone qw( clone );
+
+sub init_instance {
+    my $self = shift;
+    $self->{by_name} = {};
+    $self->{by_num}  = [];
+}
+
+sub clone {
+    my $self      = shift;
+    my $evil_twin = __PACKAGE__->new;
+    $evil_twin->{from_file} = $self->{from_file};
+    my @by_num;
+    my %by_name;
+    for my $finfo ( @{ $self->{by_num} } ) {
+        my $dupe = $finfo->clone;
+        push @by_num, $dupe;
+        $by_name{ $finfo->get_name } = $dupe;
+    }
+    $evil_twin->{by_num}  = \@by_num;
+    $evil_twin->{by_name} = \%by_name;
+    return $evil_twin;
+}
 
 # Add a user-supplied Field object to the collection.
 sub add_field {
@@ -138,7 +159,7 @@ sub consolidate {
                 $infos->{$name} = $other_finfo->breed_with( $infos->{$name} );
             }
             else {
-                $infos->{$name} = clone($other_finfo);
+                $infos->{$name} = $other_finfo->clone;
             }
         }
     }
@@ -208,7 +229,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
