@@ -7,10 +7,10 @@ use base qw( KinoSearch::Index::IndexReader );
 BEGIN {
     __PACKAGE__->init_instance_vars(
         invindex    => undef,
-        sub_readers => [],
-        starts      => [],
+        sub_readers => undef,
+        starts      => undef,
         max_doc     => 0,
-        norms_cache => {},
+        norms_cache => undef,
     );
 }
 
@@ -24,6 +24,9 @@ use KinoSearch::Index::MultiTermDocs;
 
 sub init_instance {
     my $self = shift;
+    $self->{sub_readers} ||= [];
+    $self->{starts}      ||= [];
+    $self->{norms_cache} ||= {};
 
     $self->_init_sub_readers;
 }
@@ -217,7 +220,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
