@@ -6,8 +6,8 @@ use base qw( KinoSearch::Index::TermDocs );
 
 BEGIN {
     __PACKAGE__->init_instance_vars(
-        sub_readers => [],
-        starts      => [],
+        sub_readers => undef,
+        starts      => undef,
     );
 }
 our %instance_vars;
@@ -18,8 +18,10 @@ sub new {
     my %args = ( %instance_vars, @_ );
 
     # get a SegTermDocs for each segment
-    my @sub_term_docs = map { $_->term_docs } @{ $args{sub_readers} };
-    _init_child( $self, \@sub_term_docs, $args{starts} );
+    my $sub_readers = $args{sub_readers} || [];
+    my $starts      = $args{starts}      || [];
+    my @sub_term_docs = map { $_->term_docs } @$sub_readers;
+    _init_child( $self, \@sub_term_docs, $starts );
 
     return $self;
 }
@@ -354,7 +356,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
