@@ -9,15 +9,21 @@ use constant FORMAT => -1;
 BEGIN {
     __PACKAGE__->init_instance_vars(
         # members
-        infos   => {},
+        infos   => undef,
         counter => 0,
-        version => ( time * 1000 ),
+        version => undef,
     );
     __PACKAGE__->ready_get_set(qw( counter ));
 }
 
 use Time::HiRes qw( time );
 
+sub init_instance {
+    my $self = shift;
+    $self->{infos} = {};
+    $self->{version} ||= int(time * 1000);
+}
+
 # Add a SegInfo to the collection.
 sub add_info {
     my ( $self, $info ) = @_;
@@ -131,7 +137,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
