@@ -18,7 +18,7 @@ BEGIN {
         freq_stream      => undef,
         prox_stream      => undef,
         deldocs          => undef,
-        norms_readers    => {},
+        norms_readers    => undef,
     );
 
     __PACKAGE__->ready_get(
@@ -48,6 +48,7 @@ use KinoSearch::Index::DelDocs;
 sub init_instance {
     my $self = shift;
     my ( $seg_name, $invindex ) = @{$self}{ 'seg_name', 'invindex' };
+    $self->{norms_readers} = {};
 
     # initialize DelDocs
     $self->{deldocs} = KinoSearch::Index::DelDocs->new(
@@ -222,7 +223,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
