@@ -12,7 +12,7 @@ BEGIN {
         finfos     => undef,
         field_sims => undef,
         # members
-        norm_outstreams => [],
+        norm_outstreams => undef,
         fields_writer   => undef,
         postings_writer => undef,
         doc_count       => 0,
@@ -29,10 +29,11 @@ use KinoSearch::Index::IndexFileNames
 
 sub init_instance {
     my $self = shift;
-    my ( $invindex, $norm_outstreams, $seg_name, $finfos )
-        = @{$self}{ 'invindex', 'norm_outstreams', 'seg_name', 'finfos' };
+    my ( $invindex, $seg_name, $finfos )
+        = @{$self}{ 'invindex', 'seg_name', 'finfos' };
 
     # init norms
+    my $norm_outstreams = $self->{norm_outstreams} = [];
     my @indexed_field_nums = map { $_->get_field_num }
         grep { $_->get_indexed } $finfos->get_infos;
     for my $field_num (@indexed_field_nums) {
@@ -273,7 +274,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
