@@ -9,9 +9,9 @@ BEGIN {
         # params / members
         field         => undef,
         text          => undef,
-        positions     => [],
-        start_offsets => [],
-        end_offsets   => [],
+        positions     => undef,
+        start_offsets => undef,
+        end_offsets   => undef,
     );
     __PACKAGE__->ready_get_set(
         qw(
@@ -24,6 +24,10 @@ BEGIN {
     );
 }
 
+sub init_instance {
+    my $self = shift;
+    $self->{$_} ||= [] for qw( positions start_offsets end_offsets );
+}
 1;
 
 __END__
@@ -46,7 +50,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
