@@ -17,19 +17,20 @@ BEGIN {
 
         # members
         reader       => undef,
-        analyzers    => {},
+        analyzers    => undef,
         sinfos       => undef,
         finfos       => undef,
         doc_template => undef,
+        frozen_doc   => undef,
         similarity   => undef,
-        field_sims   => {},
+        field_sims   => undef,
         seg_writer   => undef,
         write_lock   => undef,
         state        => UNINITIALIZED,
     );
 }
 
-use Clone qw( clone );
+use Storable qw( freeze thaw );
 use File::Spec::Functions qw( catfile tmpdir );
 
 use KinoSearch::Document::Doc;
@@ -48,6 +49,8 @@ use KinoSearch::Search::Similarity;
 
 sub init_instance {
     my $self = shift;
+    $self->{analyzers}  = {};
+    $self->{field_sims} = {};
 
     # use a no-op Analyzer if not supplied
     $self->{analyzer} ||= KinoSearch::Analysis::Analyzer->new;
@@ -136,6 +139,7 @@ sub _delayed_init {
     for my $field ( $doc->get_fields ) {
         $field->set_field_num( $finfos->get_field_num( $field->get_name ) );
     }
+    $self->{frozen_doc} = freeze($doc);
 
     # set sim for each field
     my $main_sim = $self->{similarity};
@@ -191,7 +195,7 @@ sub spec_field {
 sub new_doc {
     my $self = shift;
     $self->_delayed_init unless $self->{state} == INITIALIZED;
-    return clone( $self->{doc_template} );
+    return thaw( $self->{frozen_doc} );
 }
 
 sub set_similarity {
@@ -605,7 +609,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
 
