@@ -12,8 +12,8 @@ BEGIN {
         default_field  => undef,    # back compat
         fields         => undef,
         # members
-        bool_groups   => {},
-        phrases       => {},
+        bool_groups   => undef,
+        phrases       => undef,
         bool_group_re => undef,
         phrase_re     => undef,
         label_inc     => 0,
@@ -29,6 +29,8 @@ use KinoSearch::Index::Term;
 
 sub init_instance {
     my $self = shift;
+    $self->{bool_groups} = {};
+    $self->{phrases}     = {};
 
     croak("default_boolop must be either 'AND' or 'OR'")
         unless $self->{default_boolop} =~ /^(?:AND|OR)$/;
@@ -96,9 +98,9 @@ my $field_re = qr/^
              /xsm;
 
 sub parse {
-    my ( $self, $qstring_orig ) = @_;
+    my ( $self, $qstring_orig, $default_fields ) = @_;
     $qstring_orig = '' unless defined $qstring_orig;
-    my $default_fields = $self->{fields};
+    $default_fields ||= $self->{fields};
     my $default_boolop = $self->{default_boolop};
     my @clauses;
 
@@ -158,7 +160,7 @@ sub parse {
         elsif (s/$self->{bool_group_re}//) {
             # parse boolean subqueries recursively
             my $inner_text = delete $self->{bool_groups}{$1};
-            my $query      = $self->parse($inner_text);
+            my $query      = $self->parse($inner_text, $fields);
             push @clauses, { query => $query, occur => $occur };
         }
         # what's left is probably a term
@@ -331,6 +333,10 @@ Field-specific terms, in the form of C<fieldname:termtext>.  (The field
 specified by fieldname will be used instead of the QueryParser's default
 fields).
 
+A field can also be given to a logical group, in which case it is the same as
+if the field had been prepended onto every term in the group.  For example:
+C<foo:(bar baz)> is the same as C<foo:bar foo:baz>.
+
 =back
 
 =head1 METHODS
@@ -385,7 +391,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
 
