@@ -9,7 +9,7 @@ BEGIN {
         # constructor args / members
         disable_coord => 0,
         # members
-        clauses          => [],
+        clauses          => undef,
         max_clause_count => 1024,
     );
     __PACKAGE__->ready_get(qw( clauses ));
@@ -17,6 +17,11 @@ BEGIN {
 
 use KinoSearch::Search::BooleanClause;
 
+sub init_instance {
+    my $self = shift;
+    $self->{clauses} = [];
+}
+
 # Add an subquery tagged with boolean characteristics.
 sub add_clause {
     my $self   = shift;
@@ -57,20 +62,7 @@ sub create_weight {
 
 }
 
-sub clone {
-    my $self = shift;
-
-    # remove then restore clauses in case some queries aren't clone-safe.
-    my $clauses   = delete $self->{clauses};
-    my $evil_twin = Clone::clone($self);
-    $self->{clauses} = $clauses;
-
-    # clone each Clause in turn
-    my @cloned_clauses = map { $_->clone } @$clauses;
-    $evil_twin->{clauses} = \@cloned_clauses;
-
-    return $evil_twin;
-}
+sub clone { shift->todo_death }
 
 package KinoSearch::Search::BooleanWeight;
 use strict;
@@ -81,7 +73,7 @@ use base qw( KinoSearch::Search::Weight );
 BEGIN {
     __PACKAGE__->init_instance_vars(
         # members
-        weights => [],
+        weights => undef,
     );
 }
 
@@ -89,6 +81,7 @@ use KinoSearch::Search::BooleanScorer;
 
 sub init_instance {
     my $self = shift;
+    $self->{weights} = [];
     my ( $weights, $searcher ) = @{$self}{ 'weights', 'searcher' };
 
     $self->{similarity} = $self->{parent}->get_similarity($searcher);
@@ -229,7 +222,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
 
