@@ -10,8 +10,8 @@ BEGIN {
         slop => 0,
         # members
         field     => undef,
-        terms     => [],
-        positions => [],
+        terms     => undef,
+        positions => undef,
     );
     __PACKAGE__->ready_get_set(qw( slop ));
     __PACKAGE__->ready_get(qw( terms ));
@@ -21,6 +21,12 @@ use KinoSearch::Search::TermQuery;
 use KinoSearch::Document::Field;
 use KinoSearch::Util::ToStringUtils qw( boost_to_string );
 
+sub init_instance {
+    my $self = shift;
+    $self->{terms}     = [];
+    $self->{positions} = [];
+}
+
 # Add a term/position combo to the query.  The position is specified
 # explicitly in order to allow for phrases with gaps, two terms at the same
 # position, etc.
@@ -100,10 +106,11 @@ sub scorer {
     # look up each term
     my @term_docs;
     for my $term ( @{ $query->{terms} } ) {
-        my $td = $reader->term_docs($term);
 
         # bail if any one of the terms isn't in the index
-        return unless defined $td;
+        return unless $reader->doc_freq($term);;
+
+        my $td = $reader->term_docs($term);
         push @term_docs, $td;
 
         # turn on positions
@@ -113,11 +120,12 @@ sub scorer {
     # bail if there are no terms
     return unless @term_docs;
 
+    my $norms_reader = $reader->norms_reader( $query->{field} );
     return KinoSearch::Search::PhraseScorer->new(
         weight         => $self,
         slop           => $query->{slop},
         similarity     => $self->{similarity},
-        norms_reader   => $reader->norms_reader( $query->{field} ),
+        norms_reader   => $norms_reader,
         term_docs      => \@term_docs,
         phrase_offsets => $query->{positions},
     );
@@ -167,7 +175,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
 
