@@ -8,8 +8,8 @@ BEGIN {
     __PACKAGE__->init_instance_vars(
         # constructor params
         weight         => undef,
-        term_docs      => [],
-        phrase_offsets => [],
+        term_docs      => undef,
+        phrase_offsets => undef,
         norms_reader   => undef,
         slop           => 0,
     );
@@ -17,10 +17,10 @@ BEGIN {
 our %instance_vars;
 
 sub new {
-    my $self = shift->SUPER::new;
+    my $either = shift;
     confess kerror() unless verify_args( \%instance_vars, @_ );
     my %args = ( %instance_vars, @_ );
-
+    my $self = $either->SUPER::new;
     $self->_init_child;
 
     # set/derive some member vars
@@ -281,7 +281,6 @@ Kino_PhraseScorer_calc_phrase_freq(Scorer *scorer) {
     U32               *new_anchors;
     U32               *candidates;
     U32               *candidates_end;
-    U32                target;
     U32                phrase_offset;
     U32                i;
     STRLEN             len;
@@ -314,6 +313,24 @@ Kino_PhraseScorer_calc_phrase_freq(Scorer *scorer) {
             = (U32*)SvEND( term_docs[i]->get_positions(term_docs[i]) );
 
         while (anchors < anchors_end) {
+            U32 target;
+
+            /* Discard positions that occur too early in the field to match as
+             * a part of the phrase.  For example, if the field begins with
+             * "The ants go marching one by one", that initial "the" cannot
+             * match as the second term in a phrase search for 
+             * "fight the power".
+             */
+            target = phrase_offset;
+            while (candidates < candidates_end && *candidates < target) {
+                candidates++;
+            }
+            if (candidates == candidates_end)
+                break;
+
+            /* Discard partial matches which seemed promising earlier but
+             * which fail on this go-round.
+             */
             target = *candidates - phrase_offset;
             while (anchors < anchors_end && *anchors < target) {
                 anchors++;
@@ -321,14 +338,19 @@ Kino_PhraseScorer_calc_phrase_freq(Scorer *scorer) {
             if (anchors == anchors_end)
                 break;
 
+            /* Blast past any positions for the current term which are too low
+             * for the partial phrase matched in earlier iters.
+             */
             target = *anchors + phrase_offset;
             while (candidates < candidates_end && *candidates < target) {
                 candidates++;
             }
             if (candidates == candidates_end)
                 break;
-            if (*candidates == *anchors + phrase_offset) {
-                /* the anchor has made it through another elimination round */
+
+            /* Does the current position fall into the slot? */
+            if (*candidates == target) {
+                /* The anchor has made it through another elimination round. */
                 *new_anchors = *anchors;
                 new_anchors++;
             }
@@ -404,7 +426,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
