@@ -8,7 +8,7 @@ BEGIN {
     __PACKAGE__->init_instance_vars(
         # members
         similarity => undef,
-        field_sims => {},
+        field_sims => undef, # {}
     );
 }
 
@@ -142,7 +142,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =end devdocs
 =cut
