@@ -7,7 +7,7 @@ use base qw( KinoSearch::Store::InvIndex );
 BEGIN {
     __PACKAGE__->init_instance_vars(
         # members
-        ramfiles => {},
+        ramfiles => undef,
     );
 }
 
@@ -19,6 +19,7 @@ use KinoSearch::Store::RAMLock;
 
 sub init_instance {
     my $self = shift;
+    $self->{ramfiles} = {};
 
     # read in an FSInvIndex if specified
     $self->_read_invindex if defined $self->{path};
@@ -147,6 +148,6 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.07.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
