@@ -3,7 +3,6 @@ use strict;
 use warnings;
 use KinoSearch::Util::ToolSet;
 
-use Clone 'clone';
 use KinoSearch::Util::VerifyArgs qw( verify_args kerror );
 
 sub new {
@@ -27,12 +26,8 @@ sub new {
         confess kerror() unless verify_args( $defaults, @_ );
     }
 
-    # merge var => val pairs into new object
-    my $self = clone($defaults);
-    bless $self, $class;
-    %$self = ( %$self, @_ );
-
-    # call customizable initialization routine
+    # merge var => val pairs into new object, call customizable init routine
+    my $self = bless { %$defaults, @_ }, $class;
     $self->init_instance;
 
     return $self;
@@ -59,6 +54,7 @@ sub init_instance_vars {
     my $package = shift;
 
     no strict 'refs';
+    no warnings 'once';
     my $first_isa = ${ $package . '::ISA' }[0];
     %{ $package . '::instance_vars' }
         = ( %{ $first_isa . '::instance_vars' }, @_ );
@@ -190,7 +186,7 @@ as arguments to new().
         __PACKAGE__->init_instance_vars(
             # constructor params / members
             foo => undef,
-            bar => {},
+            bar => 10,
             # members
             baz => '',
         );
@@ -208,8 +204,8 @@ as arguments to new().
         boffo => $boffo,
     );
 
-%instance_vars may contain hashrefs and array-refs, as L<Clone|Clone>'s
-C<clone()> method is used to produce a deep copy.
+%instance_vars may only contain scalar values, as the defaults are merged
+into the object using a shallow copy.
 
 init_instance_vars() must be called from within a BEGIN block and before any
 C<use> directives load a child class -- if children are born before their
@@ -223,9 +219,9 @@ A generic constructor with basic argument checking.  new() expects hash-style
 labeled parameters; the label names must be present in the %instance_vars
 hash, or it will croak().
 
-After verifying the labeled parameters, new() creates a deep clone of
-%instance_vars, and merges in the labeled arguments.  It then calls
-$self->init_instance() before returning the blessed reference.
+After verifying the labeled parameters, new() merges %instance_vars and @_
+into a new object.  It then calls $self->init_instance() before returning the
+blessed reference.
 
 =head2 init_instance
 
@@ -277,7 +273,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.15.
+See L<KinoSearch|KinoSearch> version 0.16.
 
 =cut
 
